==> vala-0.3.2.tar.gz: vala-0.3.2/vala/valaarraylengthfield.c <==
/* valaarraylengthfield.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <vala/valaarraylengthfield.h>
#include <vala/valacodenode.h>
#include <vala/valasymbol.h>




enum  {
	VALA_ARRAY_LENGTH_FIELD_DUMMY_PROPERTY
};
static gpointer vala_array_length_field_parent_class = NULL;



/**
 * Creates a new array length field.
 *
 * @return newly created field
 */
ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference) {
	ValaArrayLengthField * self;
	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
	self = g_object_newv (VALA_TYPE_ARRAY_LENGTH_FIELD, 0, NULL);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
	vala_symbol_set_name (VALA_SYMBOL (self), "length");
	return self;
}


static void vala_array_length_field_class_init (ValaArrayLengthFieldClass * klass) {
	vala_array_length_field_parent_class = g_type_class_peek_parent (klass);
}


static void vala_array_length_field_init (ValaArrayLengthField * self) {
}


GType vala_array_length_field_get_type (void) {
	static GType vala_array_length_field_type_id = 0;
	if (G_UNLIKELY (vala_array_length_field_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayLengthFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_length_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayLengthField), 0, (GInstanceInitFunc) vala_array_length_field_init };
		vala_array_length_field_type_id = g_type_register_static (VALA_TYPE_FIELD, "ValaArrayLengthField", &g_define_type_info, 0);
	}
	return vala_array_length_field_type_id;
}

==> vala-0.3.5.tar.gz: vala-0.3.5/vala/valaarraylengthfield.c <==
/* valaarraylengthfield.vala
 *
 * Copyright (C) 2007-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <vala/valaarraylengthfield.h>
#include <vala/valasymbol.h>
#include <vala/valacodenode.h>




enum  {
	VALA_ARRAY_LENGTH_FIELD_DUMMY_PROPERTY
};
static gpointer vala_array_length_field_parent_class = NULL;



/**
 * Creates a new array length field.
 *
 * @return newly created field
 */
ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference) {
	ValaArrayLengthField * self;
	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
	self = g_object_newv (VALA_TYPE_ARRAY_LENGTH_FIELD, 0, NULL);
	vala_symbol_set_name (VALA_SYMBOL (self), "length");
	vala_symbol_set_external (VALA_SYMBOL (self), TRUE);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
	return self;
}


static void vala_array_length_field_class_init (ValaArrayLengthFieldClass * klass) {
	vala_array_length_field_parent_class = g_type_class_peek_parent (klass);
}


static void vala_array_length_field_instance_init (ValaArrayLengthField * self) {
}


GType vala_array_length_field_get_type (void) {
	static GType vala_array_length_field_type_id = 0;
	if (vala_array_length_field_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayLengthFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_length_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayLengthField), 0, (GInstanceInitFunc) vala_array_length_field_instance_init };
		vala_array_length_field_type_id = g_type_register_static (VALA_TYPE_FIELD, "ValaArrayLengthField", &g_define_type_info, 0);
	}
	return vala_array_length_field_type_id;
}
